@@ -5,7 +5,7 @@ import difflib
 import string
 
 
-BAD_TOKENS = ["voting district", "-", "#", "(", ")", ",", "twp", "township"]
+BAD_TOKENS = ["voting district", "-", "#", "(", ")", ",", "twp", "township", "/", "'"]
 # COMMON_REPLACEMENTS = {"pct": "precinct", "division": "district", "wd": "ward"}
 COMMON_REPLACEMENTS = {"pct": "precinct",
                        "division": "district",
@@ -14,6 +14,7 @@ COMMON_REPLACEMENTS = {"pct": "precinct",
                        "d": "district",
                        "boro": "borough",
                        "twp": "township",
+                       "tp": "township",
                        "first": "1",
                        "second": "2",
                        "third": "3",
@@ -32,11 +33,39 @@ COMMON_REPLACEMENTS = {"pct": "precinct",
                        "7th": "7",
                        "8th": "8",
                        "9th": "9",
-                       "0th": "0"}
+                       "10th": "10",
+                       "one": "1",
+                       "two": "2",
+                       "three": "3",
+                       "four": "4",
+                       "five": "5",
+                       "six": "6",
+                       "seven": "7",
+                       "eight": "8",
+                       "nine": "9",
+                       "ten": "10",
+                       "n":"north",
+                       "e":"east",
+                       "s":"south",
+                       "w":"west",
+                       "i": "1",
+                       "ii": "2",
+                       "iii": "3",
+                       "no": "number",
+                       "st": "street",
+                       "ht": "heights",
+                       "hl": "hills",
+                       "pk": "park",
+                       "mt": "mountain",
+                       "mount": "mountain",
+                       "ind": "independent"
+                       }
 
-ACCEPTABLE_DIFFERENCES = set(["district", "ward", "precinct", "borough"])
+ACCEPTABLE_DIFFERENCES = set(["district", "ward", "precinct", "borough", "number"])
 # TODO: Check with ppl about "twp" and if it is ok to map ward to precinct
-AGGRESSIVE_REPLACEMENTS = {"wd": "precinct", "ward": "precinct"} # never used
+AGGRESSIVE_REPLACEMENTS = {"wd": "precinct",
+                           "ward": "precinct"
+                           } # never used
 
 class PrecinctMatcher:
     def __init__(self, primary: List[str], secondary: List[str]):
@@ -147,10 +176,11 @@ class PrecinctMatcher:
         string = string.lower()
 
         for each_bad_token in bad_tokens:
-            string = string.replace(each_bad_token, "")
+            string = string.replace(each_bad_token, " ")
 
         for each_term, each_replacement in common_replacements.items():
             string = self._replace_token(string, each_term, each_replacement)
+            string = self._replace_token(string, each_term + ".", each_replacement)
 
         tokens = string.split()
         for count, each_token in enumerate(tokens):
@@ -159,7 +189,7 @@ class PrecinctMatcher:
             except ValueError:
                 pass
 
-        return " ".join(tokens)
+        return " ".join([token.rstrip() for token in tokens if token.rstrip()])
 
     def _replace_token(self, string: str, token: str, replacement: str):
         """
